CryptographicallySecureHash

Trait CryptographicallySecureHash 

pub unsafe trait CryptographicallySecureHash: HashFunction { }
A marker trait that ensures that the marked function is cryptographicall secure.

Safety

It is up to the implementor to ensure this invariant.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors